@@ -1,13 +1,12 @@
 use std::env;
 use std::path::PathBuf;
 use std::process::{self, Command};
-use std::str;
 
 use anyhow::{Context, Result};
 use clap::Parser;
 use fs_err as fs;
 
-use crate::zig::{prepare_zig_linker, Zig};
+use crate::zig::prepare_zig_linker;
 
 /// Compile a local package and all of its dependencies
 /// using zig as linker
@@ -104,7 +103,7 @@ pub struct Build {
     no_default_features: bool,
 
     /// Build for the target triple
-    #[clap(long, value_name = "TRIPLE")]
+    #[clap(long, value_name = "TRIPLE", env = "CARGO_BUILD_TARGET")]
     target: Option<String>,
 
     /// Directory for all generated artifacts
@@ -168,20 +167,6 @@ pub struct Build {
     unstable_flags: Vec<String>,
 }
 
-#[allow(clippy::large_enum_variant)]
-#[derive(Debug, Parser)]
-#[clap(
-    version,
-    name = "cargo",
-    global_setting(clap::AppSettings::DeriveDisplayOrder)
-)]
-pub enum Opt {
-    #[clap(name = "zigbuild")]
-    Build(Build),
-    #[clap(subcommand)]
-    Zig(Zig),
-}
-
 impl Build {
     pub fn execute(&self) -> Result<()> {
         let mut build = Command::new("cargo");
